#
# spec file for package perl-Carp-Clan
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Carp-Clan
%define cpan_name Carp-Clan
Summary:        Carp::Clan Perl module
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Version:        6.04
Release:        28.3
Url:            http://search.cpan.org/dist/Carp-Clan/
Source:         http://www.cpan.org/authors/id/S/ST/STBEY/Carp-Clan-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Exception)
Requires:       perl(Test::Exception)

%description
This module is based on "'Carp.pm'" from Perl 5.005_03. It has been
modified to skip all package names matching the pattern given in the "use"
statement inside the "'qw()'" term (or argument list).

Suppose you have a family of modules or classes named "Pack::A", "Pack::B"
and so on, and each of them uses "'Carp::Clan qw(^Pack::);'" (or at least
the one in which the error or warning gets raised).

Thus when for example your script "tool.pl" calls module "Pack::A", and
module "Pack::A" calls module "Pack::B", an exception raised in module
"Pack::B" will appear to have originated in "tool.pl" where "Pack::A" was
called, and not in "Pack::A" where "Pack::B" was called, as the unmodified
"'Carp.pm'" would try to make you believe ':-)'.

This works similarly if "Pack::B" calls "Pack::C" where the exception is
raised, etcetera.

In other words, this blames all errors in the "'Pack::*'" modules on the
user of these modules, i.e., on you. ';-)'

The skipping of a clan (or family) of packages according to a pattern
describing its members is necessary in cases where these modules are not
classes derived from each other (and thus when examining '@ISA' - as in the
original "'Carp.pm'" module - doesn't help).

The purpose and advantage of this is that a "clan" of modules can work
together (and call each other) and throw exceptions at various depths down
the calling hierarchy and still appear as a monolithic block (as though
they were a single module) from the perspective of the caller.

In case you just want to ward off all error messages from the module in
which you "'use Carp::Clan'", i.e., if you want to make all error messages
or warnings to appear to originate from where your module was called (this
is what you usually used to "'use Carp;'" for ';-)'), instead of in your
module itself (which is what you can do with a "die" or "warn" anyway), you
do not need to provide a pattern, the module will automatically provide the
correct one for you.

I.e., just "'use Carp::Clan;'" without any arguments and call "carp" or
"croak" as appropriate, and they will automatically defend your module
against all blames!

In other words, a pattern is only necessary if you want to make several
modules (more than one) work together and appear as though they were only
one.

Forcing a Stack Trace
    As a debugging aid, you can force "'Carp::Clan'" to treat a "croak" as
    a "confess" and a "carp" as a "cluck". In other words, force a detailed
    stack trace to be given. This can be very helpful when trying to
    understand why, or from where, a warning or error is being generated.

    This feature is enabled either by "importing" the non-existent symbol
    'verbose', or by setting the global variable "'$Carp::Clan::Verbose'"
    to a true value.

    You would typically enable it by saying

        use Carp::Clan qw(verbose);

    Note that you can both specify a "family pattern" and the string
    "verbose" inside the "'qw()'" term (or argument list) of the "use"
    statement, but consider that a pattern of packages to skip is pointless
    when "verbose" causes a full stack trace anyway.

Authors:
--------
    Joshua ben Jore <jjore@cpan.org>
    Steffen Beyer <stbey@cpan.org>

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
### since 11.4 perl_process_packlist
### removes .packlist, perllocal.pod files
%if 0%{?suse_version} > 1130
%perl_process_packlist
%else
# do not perl_process_packlist
# remove .packlist file
%{__rm} -rf $RPM_BUILD_ROOT%perl_vendorarch
# remove perllocal.pod file
%{__rm} -f $RPM_BUILD_ROOT%perl_archlib/perllocal.pod
%endif
%perl_gen_filelist

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changes README license/*

%changelog
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Fri Jan 15 2010 anicka@suse.cz
- update to 6.04
  * Solved RT ticket #50796 (inform type of license)
  * Made the test suite compatible with Perl versions < v5.6.0
  * Re-release to resolve confusion in CPAN caused by intermediate
  release of Carp::Clan 5.4 (backport of bugfix #50560 below for
  Perls < v5.6.0)
  * Forgot to fix the bug of duplicated prefixes in _longmsg as well
  * Fixed bug of duplicated prefixes (RT ticket #50560)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Feb 25 2008 anicka@suse.cz
- update to 6.00
  * Removed the circular dependency on Object::Deadly. It was only
  used for testing and would only succeed if you already had O::D
  installed.
* Mon Jun 18 2007 anicka@suse.cz
- update to 5.9
  * Test::Exceptions is mandatory for testing.
  * bugfix
* Wed Dec 13 2006 anicka@suse.cz
- update to 5.8
  * Stop testing that ->VERSION is a specific thing.
* Thu Oct  5 2006 anicka@suse.cz
- update to 5.7
  * Stop PAUSE from attempting to index DB package.
  * test fixes
  * bugfixes
  * Use named lexicals in diag().
  * Use exists &foo/defined &foo instead of symbol table hackery.
  * Changed f() so it accepts 1st parameter of
    carp/cluck/confess/croak instead of 1/2/3/4.
  * Renamed files.
* Mon Sep 25 2006 anicka@suse.cz
- update to 5.4
  * Made Carp::Clan safe for overloaded objects.
  * Added diag() to 01_..._carp.t
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- initial version 5.3
